@@ -6,17 +6,19 @@ $type live, vod
 import logging
 import re
 from urllib.parse import urlsplit, urlunsplit
+from uuid import uuid4
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.dash import DASHStream
 from streamlink.stream.hls import HLSStream
 
+
 log = logging.getLogger(__name__)
 
 
 @pluginmatcher(re.compile(
-    r"https?://(?:www\.)?vidio\.com/"
+    r"https?://(?:www\.)?vidio\.com/.+",
 ))
 class Vidio(Plugin):
     tokens_url = "https://www.vidio.com/live/{id}/tokens"
@@ -27,6 +29,10 @@ class Vidio(Plugin):
             self.tokens_url.format(id=stream_id),
             params={"type": stream_type},
             headers={"Referer": self.url},
+            cookies={
+                "ahoy_visit": str(uuid4()),
+                "ahoy_visitor": str(uuid4()),
+            },
             schema=validate.Schema(
                 validate.parse_json(),
                 {"token": str},
@@ -59,7 +65,7 @@ class Vidio(Plugin):
             return DASHStream.parse_manifest(
                 self.session,
                 dash_url,
-                headers={"Referer": self.url},
+                headers={"Referer": "https://www.vidio.com/"},
             )
 
         if not hls_url:
@@ -72,7 +78,7 @@ class Vidio(Plugin):
         return HLSStream.parse_variant_playlist(
             self.session,
             hls_url,
-            headers={"Referer": self.url},
+            headers={"Referer": "https://www.vidio.com/"},
         )
 
 
